@@ -19,9 +19,11 @@
 # You should have received a copy of the GNU General Public License
 # along with gcmpy. If not, see <http://www.gnu.org/licenses/gpl.html>.
 
+from .version import __version__
 from .types import *
 from .joint_degree import *
 from .gcm_algorithm import *
 from .motif_generators import *
 from .distributions import *
+from .covers import *
 from .utils import *
