@@ -18,7 +18,7 @@
 # You should have received a copy of the GNU General Public License
 # along with gcmpy. If not, see <http://www.gnu.org/licenses/gpl.html>.
 
-from typing import NewType, Tuple, Dict, List, TypeVar
+from typing import NewType, Tuple, Dict, List
 
 _JDD   = NewType('_JDD', Dict[str,float])  
 _JDS   = NewType('_JDS', List[List[int]])          
@@ -29,4 +29,6 @@ _EDGE   = NewType('_EDGE', Tuple[_NODE ,_NODE])
 _NODES  = NewType('_NODES', List[_NODE])
 _EDGES  = NewType('_EDGES', List[_EDGE])
 
+_COVER = NewType('_COVER',List[List[int]])
+
 NETWORK_SIZE = 100000
